# Proporsal

Scrapman auxiliar library functions

----

# Table of contents

[TOC]

----

# Project structure

```
.
+-- scrapbag/
|   |
|   +-- collections.py
|   +-- csvs.py
|   +-- dates.py
|   +-- files.py
|   +-- geo.py
|   +-- pdfs.py
|   +-- strings.py
|   +-- version.py
|

----

# Install Dependencies
----------------------

.. code-block:: console

    $ pip install -r requirements.txt

# Generate docs
-------------
Documentation powered by sphinx.

.. code-block:: console

    $ cd docs && make docs OUTPUT_FORMAT
